summaryrefslogtreecommitdiffstats
path: root/kdecore/kallocator.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdecore/kallocator.cpp')
-rw-r--r--kdecore/kallocator.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kdecore/kallocator.cpp b/kdecore/kallocator.cpp
index 16c1b3625..c02bbf3ff 100644
--- a/kdecore/kallocator.cpp
+++ b/kdecore/kallocator.cpp
@@ -183,9 +183,9 @@ void KZoneAllocator::delBlock(MemBlock *b)
void *
KZoneAllocator::allocate(size_t _size)
{
- // Use the size of (void *) as tqalignment
- const size_t tqalignment = sizeof(void *) - 1;
- _size = (_size + tqalignment) & ~tqalignment;
+ // Use the size of (void *) as alignment
+ const size_t alignment = sizeof(void *) - 1;
+ _size = (_size + alignment) & ~alignment;
if ((unsigned long) _size + blockOffset > blockSize)
{